@@ -8,7 +8,6 @@ import time
 from tqdm import tqdm
 from pathlib import Path
 from collections import deque
-import sys
 
 
 from yolov6.utils.events import LOGGER, load_yaml
@@ -75,7 +74,8 @@ class YOLOV6:
         save_img = True,
         hide_labels = False,
         hide_conf = False,
-        view_img = False
+        view_img = False,
+        font = './yolov6/utils/Arial.ttf'
     ):
 
         self.__dict__.update(locals())
@@ -99,7 +99,8 @@ class YOLOV6:
         self.hide_labels = hide_labels
         self.hide_conf = hide_conf
         self.view_img = view_img
-        self.font = Inferer.font_check(font='./yolov6/utils/Arial.ttf')
+        self.font_path = font
+        
 
     
     def load_model(self):
@@ -157,6 +158,7 @@ class YOLOV6:
             img_ori = img_src.copy()
 
             # check image and font
+            Inferer.font_check(self.font_path)
             assert img_ori.data.contiguous, 'Image needs to be contiguous. Please apply to input images with np.ascontiguousarray(im).'
             
 
@@ -218,6 +220,9 @@ class YOLOV6:
                         save_path = str(Path(save_path).with_suffix('.mp4'))  # force *.mp4 suffix on results videos
                         vid_writer = cv2.VideoWriter(save_path, cv2.VideoWriter_fourcc(*'mp4v'), fps, (w, h))
                     vid_writer.write(img_src)
+                
+                return save_path
+                
 
     
 if __name__ == '__main__':
